"""
The discord bot for the application.
"""

import os
import logging

from discord import Intents, Interaction, app_commands
from discord.ext import commands

log = logging.getLogger(__name__)
EXTENSIONS_DIRECTORY = "src/extensions/"


class DiscordBot(commands.Bot):

    def __init__(self):
        super().__init__(command_prefix="-", intents=Intents.all())

    async def sync_app_commands(self):
        """
        Sync application commands between discord and the bot.
        """

        await self.wait_until_ready()
        await self.tree.sync()
        log.info("Application commands successfully synced")

    async def on_ready(self):
        """
        Execute init operations that require the bot to be ready.
        Ideally should not be manually called, this is handled by discord.py
        """

        await self.sync_app_commands()

    async def load_extensions(self):
        """
        Load any extensions found in the extensions dictionary.
        """

        for filename in os.listdir(EXTENSIONS_DIRECTORY):
            if filename.endswith(".py"):
                await self.load_extension(f"extensions.{filename[:-3]}")
