"""
Initialize the database modules and create the database tables and default data.
"""

from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

from .models import NewsCategories, Base, DefaultNewsCategories, get_or_create
from .db import DATABASE_URL

# Initialise a database session, create the tables and insert the default data if needed
engine = create_engine(DATABASE_URL)
session = sessionmaker(bind=engine)()

# Create tables if not exists
Base.metadata.create_all(engine) 

# Gather the data for and create the default news category entries
for category in DefaultNewsCategories:
    get_or_create(session, model=NewsCategories, id=category.value, name=category.name)

session.commit()
session.close()
